@@ -2,13 +2,11 @@
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-from functools import partial
-
-from rpy.functions.functional import iterate
-
 import os
 import subprocess
 
+from rpy.functions.functional import iterate, partial
+
 process = partial(
     subprocess.Popen,
     stdout = subprocess.PIPE,
@@ -22,4 +20,4 @@ def _auto_expand(path):
     return path
 
 def system_open(path, cmd = "open"):
-    return process(tuple(iterate((cmd, ), map(_auto_expand, iterate(path)))))
\ No newline at end of file
+    return process(tuple(iterate((cmd, ), map(_auto_expand, iterate(path)))))
